//
//  DVRootViewController.m
//  DragViewDemo
//
//  Created by Andrew Carter on 3/8/13.
//  Copyright (c) 2013 WillowTree Apps. All rights reserved.
//

#import "DVRootViewController.h"

static const CGFloat DVGridInterval = 20.0f;

@interface DVRootViewController () <UIGestureRecognizerDelegate>
{
    UIView *_tileView;
    CGPoint _startPoint;
}
@end

@implementation DVRootViewController

#pragma mark - UIViewController Overrides

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self)
    {
        _tileView = [[UIView alloc] initWithFrame:CGRectMake(0.0f, 0.0f, DVGridInterval * 3.0f, DVGridInterval * 3.0f)];
        [self setupTileView];
    }
    return self;
}

- (void)viewDidLoad
{
    [self drawGrid];
    [[self view] addSubview:_tileView];
}

#pragma mark - Instance Methods

- (void)panGestureRecognizerDidPan:(UIPanGestureRecognizer *)gestureRecognizer
{
    if ([gestureRecognizer state] == UIGestureRecognizerStateBegan)
    {
        _startPoint = CGPointMake(CGRectGetMinX([_tileView frame]), CGRectGetMinY([_tileView frame]));
    }
    if ([gestureRecognizer state] == UIGestureRecognizerStateEnded)
    {
        CGFloat x = CGRectGetMinX([_tileView frame]) - ((NSInteger)CGRectGetMinX([_tileView frame]) % (NSInteger)DVGridInterval);
        CGFloat y = CGRectGetMinY([_tileView frame]) - ((NSInteger)CGRectGetMinY([_tileView frame]) % (NSInteger)DVGridInterval);
        
        [UIView animateWithDuration:0.1f delay:0.0f options:UIViewAnimationOptionCurveEaseOut animations:^{
            
            [_tileView setFrame:CGRectMake(x,
                                           y,
                                           CGRectGetWidth([_tileView bounds]),
                                           CGRectGetHeight([_tileView bounds]))];
            
        } completion:^(BOOL finished) {
            
        }];
    }
    else
    {
        CGPoint point = [gestureRecognizer translationInView:[self view]];
        [_tileView setFrame:CGRectMake(_startPoint.x + point.x,
                                       _startPoint.y + point.y,
                                       CGRectGetWidth([_tileView bounds]),
                                       CGRectGetHeight([_tileView bounds]))];
    }
}

- (void)setupTileView
{
    [_tileView setBackgroundColor:[UIColor blueColor]];
    UIPanGestureRecognizer *gestureRecognizer = [[UIPanGestureRecognizer alloc] initWithTarget:self action:@selector(panGestureRecognizerDidPan:)];
    [gestureRecognizer setDelegate:self];
    [_tileView addGestureRecognizer:gestureRecognizer];
}

- (void)drawGrid
{
    for (CGFloat y = 0.0f; y < CGRectGetHeight([[self view] bounds]); y += DVGridInterval)
    {
        UIView *view = [[UIView alloc] initWithFrame:CGRectMake(0.0f,
                                                                y,
                                                                CGRectGetWidth([[self view] bounds]),
                                                                1.0f)];
        [view setBackgroundColor:[UIColor redColor]];
        [[self view] addSubview:view];
    }
    for (CGFloat x = 0.0f; x < CGRectGetWidth([[self view] bounds]); x += DVGridInterval)
    {
        UIView *view = [[UIView alloc] initWithFrame:CGRectMake(x,
                                                                0.0f,
                                                                1.0f,
                                                                CGRectGetHeight([[self view] bounds]))];
        [view setBackgroundColor:[UIColor redColor]];
        [[self view] addSubview:view];
    }
}

#pragma mark - UIGestureRecognizerDelegate Methods


@end
